spacepy.radbelt.get_local_accel — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- radbelt - Functions supporting radiation belt diffusion codes »

# spacepy.radbelt.get_local_accel

`spacepy.radbelt.` `get_local_accel`(Lgrid, params, SRC_model='JK1')

  calculate the diffusion coefficient D_LL

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- radbelt - Functions supporting radiation belt diffusion codes »